@@ -20,7 +20,8 @@
 #' @param preds_levels The desired levels of the predicted binary outcome. If not defined, levels of the outcome variable are used.
 #' @param outcome_base Base level for the target variable used to compute fairness metrics. Default is the first level of the outcome variable.
 #' @param cutoff Cutoff to generate predicted outcomes from predicted probabilities. Default set to 0.5.
-#' @param base Base level for sensitive group comparison
+#' @param base Base level for sensitive group comparison.
+#' @param group_breaks If group is continuous (e.g., age): either a numeric vector of two or more unique cut points or a single number >= 2 giving the number of intervals into which group feature is to be cut.
 #'
 #' @name acc_parity
 #'
@@ -41,8 +42,13 @@
 #' @export
 
 acc_parity <- function(data, outcome, group,
-                       probs = NULL, preds = NULL, preds_levels = NULL, outcome_base = NULL, 
-                       cutoff = 0.5, base = NULL) {
+                       probs = NULL, 
+                       preds = NULL, 
+                       preds_levels = NULL, 
+                       outcome_base = NULL, 
+                       cutoff = 0.5, 
+                       base = NULL,
+                       group_breaks = NULL) {
     
     # check if data is data.frame
     if (class(data)[1] != 'data.frame') {
@@ -66,6 +72,18 @@ acc_parity <- function(data, outcome, group,
         preds_status <- as.factor(as.numeric(probs > cutoff))
     }
     
+    # check group feature and cut if needed
+    if ((length(unique(data[, group])) > 10) & (is.null(group_breaks))) {
+        warning('Number of unqiue group levels exceeds 10. Consider specifying `group_breaks`.')
+    }
+    if (!is.null(group_breaks)) {
+        if (is.numeric(data[, group])) {
+            data[, group] <- cut(data[, group], breaks = group_breaks)
+        }else{
+            warning('Attempting to bin a non-numeric group feature.')
+        }
+    }
+    
     group_status   <- as.factor(data[, group])
     outcome_status <- as.factor(data[, outcome])
     
@@ -88,9 +106,10 @@ acc_parity <- function(data, outcome, group,
     }
     group_status <- relevel(group_status, base)
 
-    # placeholder
-    val <- rep(NA, length(levels(group_status)))
-    names(val) <- levels(group_status)
+    # placeholders
+    val         <- rep(NA, length(levels(group_status)))
+    names(val)  <- levels(group_status)
+    sample_size <- val
     
     # set outcome base
     if (is.null(outcome_base)) {
@@ -103,12 +122,14 @@ acc_parity <- function(data, outcome, group,
                                      outcome_status[group_status == i], 
                                      mode = 'everything',
                                      positive = outcome_base)
-        metric_i <- cm$overall['Accuracy']
-        val[i] <- metric_i
+        metric_i       <- cm$overall['Accuracy']
+        val[i]         <- metric_i
+        sample_size[i] <- sum(cm$table)
     }
 
-    res_table <- rbind(val, val/val[[1]])
-    rownames(res_table) <- c('Accuracy', 'Accuracy Parity')
+    # aggregate results
+    res_table <- rbind(val, val/val[[1]], sample_size)
+    rownames(res_table) <- c('Accuracy', 'Accuracy Parity', 'Group size')
 
     # conversion of metrics to df
     val_df <- as.data.frame(res_table[2, ])
@@ -132,7 +153,7 @@ acc_parity <- function(data, outcome, group,
             theme(plot.title = element_text(hjust = 0.5)) + xlim(0, 1) + geom_vline(xintercept = cutoff,
             linetype = 'dashed')
     }
-
+    
     if (is.null(probs)) {
         list(Metric = res_table, Metric_plot = p)
     } else {
